==> ocg_user-0.0.12.tar.gz: lib/src/repository/network.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_user/src/models/user.dart';
import 'package:ocg_user/src/repository/base.dart';
import 'package:http/http.dart';

class UserNetworkRepository extends UserRepository {
  final BaseClient client;

  UserNetworkRepository(TokenRepository tokenRepository, this.client)
      : super(tokenRepository);

  @override
  Future<AppResponse<List<User>>> getList(
      {int count = 10, int page = 1}) async {
    try {
      String url = "/contacts";
      var response = await client.get(
        url,
      );
      var json = jsonDecode(response.body);
      List<String> contacts = List<String>.from(json["contacts"] as List);
      Set<User> users = Set<User>();
      await Future.wait(contacts.map((val) async {
        AppResponse<User> userResponse = await getUser(val);
        if (userResponse.isSuccess) users.add(userResponse.data);
      }));
      return AppResponse.named(data: users.toList());
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<User>> getSelf() async {
    try {
      String url = "/self";
      var response = await client.get(url);
      var json = jsonDecode(response.body);
      return AppResponse.named(data: User.fromJson(json["profile"]));
    } catch (e) {
      debugPrint("Error $e");
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<User>> read(String userId) async {
    try {
      String url = "/users/$userId/";
      var response = await client.get(url);
      var json = jsonDecode(response.body);
      return AppResponse.named(data: User.fromJson(json["profile"]));
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<bool>> updateSelf(User user) async {
    try {
      String url = "/users/${user.id}/";
      await client.post(url, body: jsonEncode(user.toJson()));
      return AppResponse.named(data: true);
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<bool>> blockUser(String userId, bool block) async {
    try {
      String url = "/users/$userId/${block ? "block" : "unblock"}";
      var response = await client.post(
        url,
      );
      return AppResponse.named(data: response.statusCode == 200);
    } catch (e) {
      debugPrint(
        "Error $e",
      );
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<List<User>>> getUsersList(List<String> userIds) async {
    try {
      List<User> users = [];
      users = await Future.wait(userIds.map((e) async {
        AppResponse<User> userResponse = await getUser(e);
        if (userResponse.isSuccess) {
          return userResponse.data;
        }
      }).toList());
      users = users.where((element) => element != null).toList();
      return AppResponse.named(data: users);
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<String>> create(User object) {
    // TODO: implement create
    throw UnimplementedError();
  }

  @override
  Future<AppResponse<bool>> delete(String id) {
    // TODO: implement delete
    throw UnimplementedError();
  }

  @override
  Future<AppResponse<bool>> update(User object) {
    // TODO: implement update
    throw UnimplementedError();
  }
}

==> ocg_user-0.0.14.tar.gz: lib/src/repository/network.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_user/src/models/user.dart';
import 'package:ocg_user/src/repository/base.dart';
import 'package:http/http.dart';

class UserNetworkRepository extends UserRepository {
  final BaseClient client;

  UserNetworkRepository(TokenRepository tokenRepository, this.client)
      : super(tokenRepository);

  @override
  Future<AppResponse<List<User>>> getList(
      {int count = 10, int page = 1}) async {
    try {
      String url = "/contacts";
      var response = await client.get(
        url,
      );
      var json = jsonDecode(response.body);
      List<String> contacts = List<String>.from(json["contacts"] as List);
      Set<User> users = Set<User>();
      await Future.wait(contacts.map((val) async {
        AppResponse<User> userResponse = await read(val);
        if (userResponse.isSuccess) users.add(userResponse.data);
      }));
      return AppResponse.named(data: users.toList());
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<User>> getSelf() async {
    try {
      String url = "/self";
      var response = await client.get(url);
      var json = jsonDecode(response.body);
      return AppResponse.named(data: User.fromJson(json["profile"]));
    } catch (e) {
      debugPrint("Error $e");
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<User>> read(String userId) async {
    try {
      String url = "/users/$userId/";
      var response = await client.get(url);
      var json = jsonDecode(response.body);
      User user = User.fromJson(json["profile"]);
      // Last Seen Bug
      String lastseen = json["profile"]["lastseen"];
      DateTime time = DateTime.parse(lastseen);
      DateTime nowtime = DateTime.now();
      time = time.add(nowtime.timeZoneOffset);
      return AppResponse.named(data: user.copyWith(lastSeen: time));
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<bool>> updateSelf(User user) async {
    try {
      String url = "/users/${user.id}/";
      await client.post(url, body: jsonEncode(user.toJson()));
      return AppResponse.named(data: true);
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<bool>> blockUser(String userId, bool block) async {
    try {
      String url = "/users/$userId/${block ? "block" : "unblock"}";
      var response = await client.post(
        url,
      );
      return AppResponse.named(data: response.statusCode == 200);
    } catch (e) {
      debugPrint(
        "Error $e",
      );
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<List<User>>> getUsersList(List<String> userIds) async {
    try {
      List<User> users = [];
      users = await Future.wait(userIds.map((e) async {
        AppResponse<User> userResponse = await read(e);
        if (userResponse.isSuccess) {
          return userResponse.data;
        }
      }).toList());
      users = users.where((element) => element != null).toList();
      return AppResponse.named(data: users);
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<String>> create(User object) {
    // TODO: implement create
    throw UnimplementedError();
  }

  @override
  Future<AppResponse<bool>> delete(String id) {
    // TODO: implement delete
    throw UnimplementedError();
  }

  @override
  Future<AppResponse<bool>> update(User object) {
    // TODO: implement update
    throw UnimplementedError();
  }
}
